from ftw.trash.trasher import Trasher
from ftw.trash.utils import is_trash_profile_installed


def manage_trashObjects(self, ids=None, REQUEST=None):
    """Marks objects as trashed.
    """
    if ids is None:
        ids = []
    if isinstance(ids, basestring):
        ids = [ids]
    for id_ in ids:
        Trasher(self._getOb(id_)).trash()


def manage_delObjects(self, ids=None, REQUEST=None):
    if is_trash_profile_installed():
        return self.manage_trashObjects(ids=ids, REQUEST=REQUEST)
    else:
        return self._old_manage_delObjects(ids=ids, REQUEST=REQUEST)


def searchResults(self, REQUEST=None, **kw):
    kw = kw.copy()

    # Meaning of indexed values of 'trashed':
    # - True => object is trashed
    # - False => object is not trashed
    # - None => object is not properly indexed -> treat like False

    # Meaing and defaults when querying 'trashed':
    # - True => only return trashed objects
    # - False => return trashed objects (includes not properly indexed objects)
    # - None => return all objects, do not filter
    kw.setdefault('trashed', False)

    if kw['trashed'] is False:
        kw['trashed'] = [False, None]
    elif kw['trashed'] is None:
        kw['trashed'] = [True, False, None]

    return self._old_searchResults(REQUEST, **kw)



from Products.CMFCore.utils import getToolByName
from zope.component.hooks import getSite


def is_trash_profile_installed():
    portal_setup = getToolByName(getSite(), 'portal_setup')
    return portal_setup.getLastVersionForProfile('ftw.trash:default') != 'unknown'



from ftw.trash.testing import TRASH_NOT_INSTALLED_FUNCTIONAL
from ftw.trash.tests import FunctionalTestCase
from ftw.trash.utils import is_trash_profile_installed


class TestUtilsWhenInstalled(FunctionalTestCase):

    def test_is_trash_profile_installed(self):
        self.assertTrue(is_trash_profile_installed())


class TestUtilsWhenNotInstalled(FunctionalTestCase):
    layer = TRASH_NOT_INSTALLED_FUNCTIONAL

    def test_is_trash_profile_installed(self):
        self.assertFalse(is_trash_profile_installed())
